@@ -7,7 +7,8 @@ function(min=0, max=1)
             timer = timerProgressBar(min = min, max = max,
                 initial = control$initial,
                 style = control$style, width = control$txt.width,
-                char = control$char),
+                char = control$char,
+                min_time = control$min_time),
             txt = txtProgressBar(min = min, max = max,
                 initial = control$initial,
                 style = control$style, width = control$txt.width,
